<?php

/*
 * LMS version 1.1.5 Amaonet
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: netlist.php,v 1.20 2003/09/01 12:37:02 lukasz Exp $
 */

$layout[pagetitle]="Sieci IP";

$netlist = $LMS->GetNetworkList();

$listdata[size] = $netlist[size];
$listdata[assigned] = $netlist[assigned];

unset($netlist[assigned], $netlist[size], $netlist[total]);

$listdata[total] = sizeof($netlist);

$SMARTY->assign("listdata",$listdata);
$SMARTY->assign("netadd",$netadd);
$SMARTY->assign("layout",$layout);
$SMARTY->assign("netlist",$netlist);
$SMARTY->display("netlist.html");
/*
 * $Log: netlist.php,v $
 * Revision 1.20  2003/09/01 12:37:02  lukasz
 * - BTS #0000067
 *
 * Revision 1.19  2003/08/27 19:25:56  lukasz
 * - changed format of ipaddr storage in database
 *
 * Revision 1.18  2003/08/24 13:12:54  lukasz
 * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
 *   redhat's :>
 *
 * Revision 1.17  2003/08/18 16:52:19  lukasz
 * - added CVS Log tags
 *
 */
?>
